'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _toArray(arr) { return Array.isArray(arr) ? arr : Array.from(arr); }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var mbxGeocoding = require('@mapbox/mapbox-sdk/services/geocoding');
var geocodingClient = mbxGeocoding({
  accessToken: process.env.MB_PUBLIC_TOKEN
});

var geocodeByAddress = function geocodeByAddress(_ref) {
  var input = _ref.input,
      options = _objectWithoutProperties(_ref, ['input']);

  return new Promise(function (resolve, reject) {
    geocodingClient.forwardGeocode(_extends({
      query: input
    }, options)).send().then(function (response) {
      var suggestions = [];
      var match = response.body;
      match.features.map(function (suggestion) {
        var postcodeObj = suggestion.context.find(function (el) {
          return el.id.includes('postcode');
        });
        var countryObj = suggestion.context.find(function (el) {
          return el.id.includes('country');
        });

        var _suggestion$place_nam = suggestion.place_name.split(','),
            _suggestion$place_nam2 = _toArray(_suggestion$place_nam),
            main = _suggestion$place_nam2[0],
            secondary = _suggestion$place_nam2.slice(1);

        var rest = secondary.map(function (el) {
          if (postcodeObj && el.includes(postcodeObj.text)) {
            var noPost = el.replace(postcodeObj.text, '').trim();
            return noPost !== '' && el.replace(postcodeObj.text, '').trim() + ',';
          } else if (countryObj && el.trim() === countryObj.text) {
            return countryObj.short_code.toUpperCase();
          }
          return el.trim() + ',';
        });

        suggestions.push({
          id: suggestion.id,
          main: main,
          rest: rest && rest.join(' '),
          lat: suggestion.center[0],
          lng: suggestion.center[1]
        });
      });
      resolve(suggestions);
    }).catch(function (error) {
      reject(error);
    });
  });
};

exports.geocodeByAddress = geocodeByAddress;
var getLatLng = exports.getLatLng = function getLatLng(result) {
  var latLng = {
    lat: result.lat,
    lng: result.lng
  };
  return latLng;
};

var geocodeByPlaceId = exports.geocodeByPlaceId = function geocodeByPlaceId(placeId) {
  var geocoder = new window.google.maps.Geocoder();
  var OK = window.google.maps.GeocoderStatus.OK;

  return new Promise(function (resolve, reject) {
    geocoder.geocode({ placeId: placeId }, function (results, status) {
      if (status !== OK) {
        reject(status);
      }
      resolve(results);
    });
  });
};